# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.4](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.3...aoe2rec-py-v0.1.4) - 2025-01-13

### Fixed

- Increase minimum version requirement to 3.9
- Try and support python versions older than 3.12

## [0.1.3](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.2...aoe2rec-py-v0.1.3) - 2025-01-13

### Added

- Calculate the eAPM

## [0.1.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.1...aoe2rec-py-v0.1.2) - 2025-01-12

### Added

- Implement get_diplomacy

## [0.1.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-py-v0.1.0...aoe2rec-py-v0.1.1) - 2025-01-12

### Added

- Implement get_settings method

## [0.1.0](https://github.com/aoe2ct/aoe2rec/releases/tag/aoe2rec-py-v0.1.0) - 2025-01-12

### Other

- Add first draft of python module implementation
